Module: Pikuri::Code::Bash::Sandbox::NONE

Defined in:
lib/pikuri/code/bash/sandbox.rb

Overview

Identity sandbox — passthrough. The Bash.new default and the --no-sandbox / --yolo opt-out.

Class Method Summary collapse

Class Method Details

.confined_to_workspace?Boolean

Returns false — an unwrapped command has the host's whole filesystem, whatever the workspace was scoped to.

Returns:

  • (Boolean)

    false — an unwrapped command has the host's whole filesystem, whatever the workspace was scoped to



87
# File 'lib/pikuri/code/bash/sandbox.rb', line 87

def self.confined_to_workspace? = false

.egress?Boolean

Returns true — an unwrapped command has the host's network.

Returns:

  • (Boolean)

    true — an unwrapped command has the host's network



83
# File 'lib/pikuri/code/bash/sandbox.rb', line 83

def self.egress? = true

.wrap(argv) ⇒ Array<String>

Returns argv unchanged.

Parameters:

  • argv (Array<String>)

Returns:

  • (Array<String>)

    argv unchanged



77
78
79
# File 'lib/pikuri/code/bash/sandbox.rb', line 77

def self.wrap(argv)
  argv
end